==> temporalio-0.1a2.tar.gz: temporalio-0.1a2/temporalio/api/workflowservice/v1/__init__.py <==
from .request_response_pb2 import (
    CountWorkflowExecutionsRequest,
    CountWorkflowExecutionsResponse,
    DeprecateNamespaceRequest,
    DeprecateNamespaceResponse,
    DescribeNamespaceRequest,
    DescribeNamespaceResponse,
    DescribeTaskQueueRequest,
    DescribeTaskQueueResponse,
    DescribeWorkflowExecutionRequest,
    DescribeWorkflowExecutionResponse,
    GetClusterInfoRequest,
    GetClusterInfoResponse,
    GetSearchAttributesRequest,
    GetSearchAttributesResponse,
    GetSystemInfoRequest,
    GetSystemInfoResponse,
    GetWorkflowExecutionHistoryRequest,
    GetWorkflowExecutionHistoryResponse,
    GetWorkflowExecutionHistoryReverseRequest,
    GetWorkflowExecutionHistoryReverseResponse,
    ListArchivedWorkflowExecutionsRequest,
    ListArchivedWorkflowExecutionsResponse,
    ListClosedWorkflowExecutionsRequest,
    ListClosedWorkflowExecutionsResponse,
    ListNamespacesRequest,
    ListNamespacesResponse,
    ListOpenWorkflowExecutionsRequest,
    ListOpenWorkflowExecutionsResponse,
    ListTaskQueuePartitionsRequest,
    ListTaskQueuePartitionsResponse,
    ListWorkflowExecutionsRequest,
    ListWorkflowExecutionsResponse,
    PollActivityTaskQueueRequest,
    PollActivityTaskQueueResponse,
    PollWorkflowTaskQueueRequest,
    PollWorkflowTaskQueueResponse,
    QueryWorkflowRequest,
    QueryWorkflowResponse,
    RecordActivityTaskHeartbeatByIdRequest,
    RecordActivityTaskHeartbeatByIdResponse,
    RecordActivityTaskHeartbeatRequest,
    RecordActivityTaskHeartbeatResponse,
    RegisterNamespaceRequest,
    RegisterNamespaceResponse,
    RequestCancelWorkflowExecutionRequest,
    RequestCancelWorkflowExecutionResponse,
    ResetStickyTaskQueueRequest,
    ResetStickyTaskQueueResponse,
    ResetWorkflowExecutionRequest,
    ResetWorkflowExecutionResponse,
    RespondActivityTaskCanceledByIdRequest,
    RespondActivityTaskCanceledByIdResponse,
    RespondActivityTaskCanceledRequest,
    RespondActivityTaskCanceledResponse,
    RespondActivityTaskCompletedByIdRequest,
    RespondActivityTaskCompletedByIdResponse,
    RespondActivityTaskCompletedRequest,
    RespondActivityTaskCompletedResponse,
    RespondActivityTaskFailedByIdRequest,
    RespondActivityTaskFailedByIdResponse,
    RespondActivityTaskFailedRequest,
    RespondActivityTaskFailedResponse,
    RespondQueryTaskCompletedRequest,
    RespondQueryTaskCompletedResponse,
    RespondWorkflowTaskCompletedRequest,
    RespondWorkflowTaskCompletedResponse,
    RespondWorkflowTaskFailedRequest,
    RespondWorkflowTaskFailedResponse,
    ScanWorkflowExecutionsRequest,
    ScanWorkflowExecutionsResponse,
    SignalWithStartWorkflowExecutionRequest,
    SignalWithStartWorkflowExecutionResponse,
    SignalWorkflowExecutionRequest,
    SignalWorkflowExecutionResponse,
    StartWorkflowExecutionRequest,
    StartWorkflowExecutionResponse,
    TerminateWorkflowExecutionRequest,
    TerminateWorkflowExecutionResponse,
    UpdateNamespaceRequest,
    UpdateNamespaceResponse,
)
from .service_pb2_grpc import WorkflowService  # type: ignore
from .service_pb2_grpc import (
    WorkflowServiceServicer,
    WorkflowServiceStub,
    add_WorkflowServiceServicer_to_server,
)

__all__ = [
    "CountWorkflowExecutionsRequest",
    "CountWorkflowExecutionsResponse",
    "DeprecateNamespaceRequest",
    "DeprecateNamespaceResponse",
    "DescribeNamespaceRequest",
    "DescribeNamespaceResponse",
    "DescribeTaskQueueRequest",
    "DescribeTaskQueueResponse",
    "DescribeWorkflowExecutionRequest",
    "DescribeWorkflowExecutionResponse",
    "GetClusterInfoRequest",
    "GetClusterInfoResponse",
    "GetSearchAttributesRequest",
    "GetSearchAttributesResponse",
    "GetSystemInfoRequest",
    "GetSystemInfoResponse",
    "GetWorkflowExecutionHistoryRequest",
    "GetWorkflowExecutionHistoryResponse",
    "GetWorkflowExecutionHistoryReverseRequest",
    "GetWorkflowExecutionHistoryReverseResponse",
    "ListArchivedWorkflowExecutionsRequest",
    "ListArchivedWorkflowExecutionsResponse",
    "ListClosedWorkflowExecutionsRequest",
    "ListClosedWorkflowExecutionsResponse",
    "ListNamespacesRequest",
    "ListNamespacesResponse",
    "ListOpenWorkflowExecutionsRequest",
    "ListOpenWorkflowExecutionsResponse",
    "ListTaskQueuePartitionsRequest",
    "ListTaskQueuePartitionsResponse",
    "ListWorkflowExecutionsRequest",
    "ListWorkflowExecutionsResponse",
    "PollActivityTaskQueueRequest",
    "PollActivityTaskQueueResponse",
    "PollWorkflowTaskQueueRequest",
    "PollWorkflowTaskQueueResponse",
    "QueryWorkflowRequest",
    "QueryWorkflowResponse",
    "RecordActivityTaskHeartbeatByIdRequest",
    "RecordActivityTaskHeartbeatByIdResponse",
    "RecordActivityTaskHeartbeatRequest",
    "RecordActivityTaskHeartbeatResponse",
    "RegisterNamespaceRequest",
    "RegisterNamespaceResponse",
    "RequestCancelWorkflowExecutionRequest",
    "RequestCancelWorkflowExecutionResponse",
    "ResetStickyTaskQueueRequest",
    "ResetStickyTaskQueueResponse",
    "ResetWorkflowExecutionRequest",
    "ResetWorkflowExecutionResponse",
    "RespondActivityTaskCanceledByIdRequest",
    "RespondActivityTaskCanceledByIdResponse",
    "RespondActivityTaskCanceledRequest",
    "RespondActivityTaskCanceledResponse",
    "RespondActivityTaskCompletedByIdRequest",
    "RespondActivityTaskCompletedByIdResponse",
    "RespondActivityTaskCompletedRequest",
    "RespondActivityTaskCompletedResponse",
    "RespondActivityTaskFailedByIdRequest",
    "RespondActivityTaskFailedByIdResponse",
    "RespondActivityTaskFailedRequest",
    "RespondActivityTaskFailedResponse",
    "RespondQueryTaskCompletedRequest",
    "RespondQueryTaskCompletedResponse",
    "RespondWorkflowTaskCompletedRequest",
    "RespondWorkflowTaskCompletedResponse",
    "RespondWorkflowTaskFailedRequest",
    "RespondWorkflowTaskFailedResponse",
    "ScanWorkflowExecutionsRequest",
    "ScanWorkflowExecutionsResponse",
    "SignalWithStartWorkflowExecutionRequest",
    "SignalWithStartWorkflowExecutionResponse",
    "SignalWorkflowExecutionRequest",
    "SignalWorkflowExecutionResponse",
    "StartWorkflowExecutionRequest",
    "StartWorkflowExecutionResponse",
    "TerminateWorkflowExecutionRequest",
    "TerminateWorkflowExecutionResponse",
    "UpdateNamespaceRequest",
    "UpdateNamespaceResponse",
    "WorkflowService",
    "WorkflowServiceServicer",
    "WorkflowServiceStub",
    "add_WorkflowServiceServicer_to_server",
]

==> temporalio-1.1.0.tar.gz: temporalio-1.1.0/temporalio/api/workflowservice/v1/__init__.py <==
from .request_response_pb2 import (
    CountWorkflowExecutionsRequest,
    CountWorkflowExecutionsResponse,
    CreateScheduleRequest,
    CreateScheduleResponse,
    DeleteScheduleRequest,
    DeleteScheduleResponse,
    DeleteWorkflowExecutionRequest,
    DeleteWorkflowExecutionResponse,
    DeprecateNamespaceRequest,
    DeprecateNamespaceResponse,
    DescribeBatchOperationRequest,
    DescribeBatchOperationResponse,
    DescribeNamespaceRequest,
    DescribeNamespaceResponse,
    DescribeScheduleRequest,
    DescribeScheduleResponse,
    DescribeTaskQueueRequest,
    DescribeTaskQueueResponse,
    DescribeWorkflowExecutionRequest,
    DescribeWorkflowExecutionResponse,
    GetClusterInfoRequest,
    GetClusterInfoResponse,
    GetSearchAttributesRequest,
    GetSearchAttributesResponse,
    GetSystemInfoRequest,
    GetSystemInfoResponse,
    GetWorkerBuildIdOrderingRequest,
    GetWorkerBuildIdOrderingResponse,
    GetWorkflowExecutionHistoryRequest,
    GetWorkflowExecutionHistoryResponse,
    GetWorkflowExecutionHistoryReverseRequest,
    GetWorkflowExecutionHistoryReverseResponse,
    ListArchivedWorkflowExecutionsRequest,
    ListArchivedWorkflowExecutionsResponse,
    ListBatchOperationsRequest,
    ListBatchOperationsResponse,
    ListClosedWorkflowExecutionsRequest,
    ListClosedWorkflowExecutionsResponse,
    ListNamespacesRequest,
    ListNamespacesResponse,
    ListOpenWorkflowExecutionsRequest,
    ListOpenWorkflowExecutionsResponse,
    ListScheduleMatchingTimesRequest,
    ListScheduleMatchingTimesResponse,
    ListSchedulesRequest,
    ListSchedulesResponse,
    ListTaskQueuePartitionsRequest,
    ListTaskQueuePartitionsResponse,
    ListWorkflowExecutionsRequest,
    ListWorkflowExecutionsResponse,
    PatchScheduleRequest,
    PatchScheduleResponse,
    PollActivityTaskQueueRequest,
    PollActivityTaskQueueResponse,
    PollWorkflowTaskQueueRequest,
    PollWorkflowTaskQueueResponse,
    QueryWorkflowRequest,
    QueryWorkflowResponse,
    RecordActivityTaskHeartbeatByIdRequest,
    RecordActivityTaskHeartbeatByIdResponse,
    RecordActivityTaskHeartbeatRequest,
    RecordActivityTaskHeartbeatResponse,
    RegisterNamespaceRequest,
    RegisterNamespaceResponse,
    RequestCancelWorkflowExecutionRequest,
    RequestCancelWorkflowExecutionResponse,
    ResetStickyTaskQueueRequest,
    ResetStickyTaskQueueResponse,
    ResetWorkflowExecutionRequest,
    ResetWorkflowExecutionResponse,
    RespondActivityTaskCanceledByIdRequest,
    RespondActivityTaskCanceledByIdResponse,
    RespondActivityTaskCanceledRequest,
    RespondActivityTaskCanceledResponse,
    RespondActivityTaskCompletedByIdRequest,
    RespondActivityTaskCompletedByIdResponse,
    RespondActivityTaskCompletedRequest,
    RespondActivityTaskCompletedResponse,
    RespondActivityTaskFailedByIdRequest,
    RespondActivityTaskFailedByIdResponse,
    RespondActivityTaskFailedRequest,
    RespondActivityTaskFailedResponse,
    RespondQueryTaskCompletedRequest,
    RespondQueryTaskCompletedResponse,
    RespondWorkflowTaskCompletedRequest,
    RespondWorkflowTaskCompletedResponse,
    RespondWorkflowTaskFailedRequest,
    RespondWorkflowTaskFailedResponse,
    ScanWorkflowExecutionsRequest,
    ScanWorkflowExecutionsResponse,
    SignalWithStartWorkflowExecutionRequest,
    SignalWithStartWorkflowExecutionResponse,
    SignalWorkflowExecutionRequest,
    SignalWorkflowExecutionResponse,
    StartBatchOperationRequest,
    StartBatchOperationResponse,
    StartWorkflowExecutionRequest,
    StartWorkflowExecutionResponse,
    StopBatchOperationRequest,
    StopBatchOperationResponse,
    TerminateWorkflowExecutionRequest,
    TerminateWorkflowExecutionResponse,
    UpdateNamespaceRequest,
    UpdateNamespaceResponse,
    UpdateScheduleRequest,
    UpdateScheduleResponse,
    UpdateWorkerBuildIdOrderingRequest,
    UpdateWorkerBuildIdOrderingResponse,
    UpdateWorkflowRequest,
    UpdateWorkflowResponse,
)

__all__ = [
    "CountWorkflowExecutionsRequest",
    "CountWorkflowExecutionsResponse",
    "CreateScheduleRequest",
    "CreateScheduleResponse",
    "DeleteScheduleRequest",
    "DeleteScheduleResponse",
    "DeleteWorkflowExecutionRequest",
    "DeleteWorkflowExecutionResponse",
    "DeprecateNamespaceRequest",
    "DeprecateNamespaceResponse",
    "DescribeBatchOperationRequest",
    "DescribeBatchOperationResponse",
    "DescribeNamespaceRequest",
    "DescribeNamespaceResponse",
    "DescribeScheduleRequest",
    "DescribeScheduleResponse",
    "DescribeTaskQueueRequest",
    "DescribeTaskQueueResponse",
    "DescribeWorkflowExecutionRequest",
    "DescribeWorkflowExecutionResponse",
    "GetClusterInfoRequest",
    "GetClusterInfoResponse",
    "GetSearchAttributesRequest",
    "GetSearchAttributesResponse",
    "GetSystemInfoRequest",
    "GetSystemInfoResponse",
    "GetWorkerBuildIdOrderingRequest",
    "GetWorkerBuildIdOrderingResponse",
    "GetWorkflowExecutionHistoryRequest",
    "GetWorkflowExecutionHistoryResponse",
    "GetWorkflowExecutionHistoryReverseRequest",
    "GetWorkflowExecutionHistoryReverseResponse",
    "ListArchivedWorkflowExecutionsRequest",
    "ListArchivedWorkflowExecutionsResponse",
    "ListBatchOperationsRequest",
    "ListBatchOperationsResponse",
    "ListClosedWorkflowExecutionsRequest",
    "ListClosedWorkflowExecutionsResponse",
    "ListNamespacesRequest",
    "ListNamespacesResponse",
    "ListOpenWorkflowExecutionsRequest",
    "ListOpenWorkflowExecutionsResponse",
    "ListScheduleMatchingTimesRequest",
    "ListScheduleMatchingTimesResponse",
    "ListSchedulesRequest",
    "ListSchedulesResponse",
    "ListTaskQueuePartitionsRequest",
    "ListTaskQueuePartitionsResponse",
    "ListWorkflowExecutionsRequest",
    "ListWorkflowExecutionsResponse",
    "PatchScheduleRequest",
    "PatchScheduleResponse",
    "PollActivityTaskQueueRequest",
    "PollActivityTaskQueueResponse",
    "PollWorkflowTaskQueueRequest",
    "PollWorkflowTaskQueueResponse",
    "QueryWorkflowRequest",
    "QueryWorkflowResponse",
    "RecordActivityTaskHeartbeatByIdRequest",
    "RecordActivityTaskHeartbeatByIdResponse",
    "RecordActivityTaskHeartbeatRequest",
    "RecordActivityTaskHeartbeatResponse",
    "RegisterNamespaceRequest",
    "RegisterNamespaceResponse",
    "RequestCancelWorkflowExecutionRequest",
    "RequestCancelWorkflowExecutionResponse",
    "ResetStickyTaskQueueRequest",
    "ResetStickyTaskQueueResponse",
    "ResetWorkflowExecutionRequest",
    "ResetWorkflowExecutionResponse",
    "RespondActivityTaskCanceledByIdRequest",
    "RespondActivityTaskCanceledByIdResponse",
    "RespondActivityTaskCanceledRequest",
    "RespondActivityTaskCanceledResponse",
    "RespondActivityTaskCompletedByIdRequest",
    "RespondActivityTaskCompletedByIdResponse",
    "RespondActivityTaskCompletedRequest",
    "RespondActivityTaskCompletedResponse",
    "RespondActivityTaskFailedByIdRequest",
    "RespondActivityTaskFailedByIdResponse",
    "RespondActivityTaskFailedRequest",
    "RespondActivityTaskFailedResponse",
    "RespondQueryTaskCompletedRequest",
    "RespondQueryTaskCompletedResponse",
    "RespondWorkflowTaskCompletedRequest",
    "RespondWorkflowTaskCompletedResponse",
    "RespondWorkflowTaskFailedRequest",
    "RespondWorkflowTaskFailedResponse",
    "ScanWorkflowExecutionsRequest",
    "ScanWorkflowExecutionsResponse",
    "SignalWithStartWorkflowExecutionRequest",
    "SignalWithStartWorkflowExecutionResponse",
    "SignalWorkflowExecutionRequest",
    "SignalWorkflowExecutionResponse",
    "StartBatchOperationRequest",
    "StartBatchOperationResponse",
    "StartWorkflowExecutionRequest",
    "StartWorkflowExecutionResponse",
    "StopBatchOperationRequest",
    "StopBatchOperationResponse",
    "TerminateWorkflowExecutionRequest",
    "TerminateWorkflowExecutionResponse",
    "UpdateNamespaceRequest",
    "UpdateNamespaceResponse",
    "UpdateScheduleRequest",
    "UpdateScheduleResponse",
    "UpdateWorkerBuildIdOrderingRequest",
    "UpdateWorkerBuildIdOrderingResponse",
    "UpdateWorkflowRequest",
    "UpdateWorkflowResponse",
]

# gRPC is optional
try:
    import grpc

    from .service_pb2_grpc import (
        WorkflowServiceServicer,
        WorkflowServiceStub,
        add_WorkflowServiceServicer_to_server,
    )

    __all__.extend(
        [
            "WorkflowServiceServicer",
            "WorkflowServiceStub",
            "add_WorkflowServiceServicer_to_server",
        ]
    )
except ImportError:
    pass
